Enum rkyv::result::ArchivedResult [−][src]
#[repr(u8)]
pub enum ArchivedResult<T, E> {
Ok(T),
Err(E),
}Variants
Ok(T)
Contains the success value
Err(E)
Contains the error value
Implementations
Returns a Result containing the success and error values of this ArchivedResult.
Converts from &mut ArchivedResult<T, E> to Result<&mut T, &mut E>.
Returns an iterator over the possibly contained value.
The iterator yields one value if the result is ArchivedResult::Ok, otherwise none.